name='qt6-qtbase'
version='6.8.0'
release='1'
desc='A cross-platform application and UI framework.'
homepage='https://www.qt.io'
maintainer_ru='Евгений Храмов <xpamych@yandex.ru>'
architectures=('amd64')
license=('GPL3' 'LGPL3' 'FDL' 'custom')
provides=('qt6-qtbase')
conflicts=('qt6-qtbase' 'qt6-qtbase-bin' 'qt6-qtbase-git' 'qt6-qtbase-ibase')

deps=(
    'brotli'
    'dbus'
    'double-conversion'
    'fontconfig'
    'freetype'
    'libgcc'
    'glib2'
    'glibc'
    'harfbuzz'
    'icu'
    'krb5-libs'
    'libb2'
    'cups-libs'
    'libdrm'
    'libglvnd-glx'
    'libICE'
    'libinput'
    'libjpeg-turbo'
    'libpng'
    'libproxy'
    'libSM'
    'libX11'
    'libxcb'
    'libxkbcommon'
    'libxkbcommon-x11'
    'md4c'
    'mesa-dri-drivers'
    'mtdev'
    'openssl'
    'pcre2'
    'shared-mime-info'
    'sqlite'
    'systemd-libs'
    'tslib'
    'vulkan-headers'
    'xcb-util-cursor'
    'xcb-util-image'
    'xcb-util-keysyms'
    'xcb-util-renderutil'
    'xcb-util-wm'
    'xdg-utils'
    'zlib'
    'zstd'
    'qt6-qttranslations'
)
build_deps=(
    'alsa-lib'
    'cmake'
    'cups'
    'freetds'
    'git'
    'gstreamer1-plugins-base'
    'gtk3'
    'libfbclient2'
    'pulseaudio-libs-devel'
    'mariadb-devel'
    'ninja-build'
    'postgresql'
    'unixODBC-devel'
    'xmlstarlet'
    'libproxy-devel'
    'sqlite-devel'
)
opt_deps=(
    'freetds: MS SQL driver'
    'gdk-pixbuf2: GTK platform plugin'
    'gtk3: GTK platform plugin'
    'libfbclient2: Firebird/iBase driver'
    'R-RMariaDB: MariaDB driver'
    'pango: GTK platform plugin'
    'perl: for syncqt'
    'postgresql-libs: PostgreSQL driver'
    'qt6-qtwayland: to run Qt6 applications in a Wayland session'
    'unixODBC: ODBC driver'
)

sources=("git+https://code.qt.io/qt/qtbase#tag=v$version")
checksums=('SKIP')

prepare() {
  patch -d qtbase -p1 < $scriptdir/qt6-base-cflags.patch
  patch -d qtbase -p1 < $scriptdir/qt6-base-nostrip.patch
}

build() {
  cmake -B build -S qtbase -G Ninja \
    -DCMAKE_INSTALL_PREFIX=/usr \
    -DCMAKE_BUILD_TYPE=RelWithDebInfo \
    -DINSTALL_BINDIR=lib/qt6/bin \
    -DINSTALL_PUBLICBINDIR=usr/bin \
    -DINSTALL_LIBEXECDIR=lib/qt6 \
    -DINSTALL_DOCDIR=share/doc/qt6 \
    -DINSTALL_ARCHDATADIR=lib/qt6 \
    -DINSTALL_DATADIR=share/qt6 \
    -DINSTALL_INCLUDEDIR=include/qt6 \
    -DINSTALL_MKSPECSDIR=lib/qt6/mkspecs \
    -DINSTALL_EXAMPLESDIR=share/doc/qt6/examples \
    -DFEATURE_journald=ON \
    -DFEATURE_libproxy=ON \
    -DFEATURE_openssl_linked=ON \
    -DFEATURE_system_sqlite=ON \
    -DFEATURE_system_xcb_xinput=ON \
    -DFEATURE_no_direct_extern_access=ON \
    -DCMAKE_INTERPROCEDURAL_OPTIMIZATION=ON \
    -DCMAKE_MESSAGE_LOG_LEVEL=STATUS
  cmake --build build -j$(($(nproc) - 1))
}

package() {
  DESTDIR="$pkgdir" cmake --install build

  install -Dm644 qtbase/LICENSES/* -t qtbase/usr/share/licenses/qtbase

# Install symlinks for user-facing tools
  cd "qtbase"
  mkdir usr/bin
  while read _line; do
    ln -s $_line
  done < "$srcdir"/build/user_facing_tool_links.txt

}



